# NIP-41 - Poll & Vote Event

`draft` `optional` `author:0xtlt`

> Poll and vote events are a way to create a poll and vote for it.\
> Polls are directly integrated into message events (1), and responses are vote events (9) to avoid overloading the loading of messages in clients.

## Specs

### Kind `1` - Message & Poll

To create a poll, include a `poll` tag in the message event. with the following format:

```json
tag: poll
options:
 - <multi|single> allow others to reply with one or multiple options
 - <ttl> TTL (in seconds|timestamp) when surv expires, 0 TTL don't expire
 - [<option>]: array of string
```

And you can also add a `poll_name` tag to add a title to the poll, but it's optional.

#### Example - Message

```json
{
  ...
  "kind": 1,
  "tags": [
    ...
    ["poll", "Option 1", "Option 2", "Option 3"],
    ["poll_name", "This is optional"]
    ...
  ],
}
```

### Kind `9` - Vote

To vote for a poll, you have to send an event kind `9`.\
The format of the event is the following:

```json
kind: 9
content: <choice, which is the index of the option | the first option is 0>
```

#### Example - Vote

```json
{
  ...
  "kind": 9,
  "tags": [
    ...
    ["e", "<event-id>"]
    ...
  ],
  "content": "1"
}
```

## Relay and client recommendations

- Options should be limited to 4 options and should not display more than **4 options** in the poll
- Each option should be 25 chars limited
- Clients should display poll options if more than **one option** is present in the poll
- Clients should ignore vote events if the poll is **expired**
- Clients should not display more than one poll per message. The first poll in the message should be displayed.

## Warning

Keep in mind that all votes are public and accessible to everyone.
